@@ -2,7 +2,7 @@ from ._private._concepts import Event, EventHandler
 from ._private._elements import \
     InternalPipelineElement, \
     EventGenerator, EventListener, \
-    EventSource, EventAnalyzer, EventSink, \
+    EventSource, EventTransformer, EventSink, \
     TriggererEventSource, TriggerableEventSource, TriggerableEventBatchSource
 from ._private._pipeline import Pipeline
 from ._private._data_types import Server
